@@ -199,7 +199,7 @@ fi
 data_fdog_file="data_HaMStR-2019c.tar.gz"
 checkSumData="1748371655 621731824 $data_fdog_file"
 cd $outDir
-if [ ! -d "$outDir/core_orthologs" ]; then mkdir "$outDir/core_orthologs"; fi
+if [ ! -d "$outDir/genome_dir" ]; then mkdir "$outDir/genome_dir"; fi
 
 if ! [ "$(ls -A $outDir/genome_dir)" ]; then
   echo "-------------------------------------"
